Hash class

Hash algorithms, Implements SHA-512, SHA-256 and Blake2b. Cryptographic secure hash functions are irreversible transforms of input data to a fixed length digest. The standard properties of a cryptographic hash make these functions useful both for standalone usage as data integrity checkers, as well as black-box building blocks of other kind of algorithms and data structures.

All of the hash functions exposed in pinenacl.hashing can be used as data integrity checkers.

Constructors

Hash()

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

blake2b(dynamic message, {int? digestSize, Uint8List? key, Uint8List? salt, Uint8List? personalisation}) → Uint8List
Returns a Blake2b hash of the message.
sha256(dynamic message) → Uint8List
Returns SHA-256 hash of the message.
sha512(dynamic message, {int? hashLength}) → Uint8List
Returns SHA-512 hash of the message.

Constants

defaultHashLength → const int